/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlUnop.h"
#include "HvControlIf.h"
#include "HvControlSlice.h"
#include "HvControlCast.h"
#include "HvSignalLine.h"
#include "HvSignalVar.h"
#include "HvControlBinop.h"
#include "HvControlSystem.h"
#include "HvMath.h"
#include "HvControlVar.h"
#include "HvSignalBiquad.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_niRulR8a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5v68Tw5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5sjXZoMv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AA2T9yvy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BbkifwyV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_1p2v0Iiz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VlZKe685_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_K9l9WH5j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Yzixk9P4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SexYL7PY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_eMVieUuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cphR5aWd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VsS7hbDO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kU4AOwwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZaWML1me_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FLv7VHuf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c1CHny1k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bwqUGoMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9swCzRyR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8YkPr3EK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wtLJ3uvm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pT7eY0i1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lOvCLwdJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8kSOsTSA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ue1kpWly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_74saEJam_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WqfW0QPN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8cTZuJTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6J5lUQ2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1LSs9Dao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vwHoah1C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_T7wG9dcQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VRQtpbfb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_41Uhi6Tf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZJRFx0kv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XkD49HHE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vxJ9ggSU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P9x06gvZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RoHJwdYb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wIo2DTPV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9m6KjFOq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5DpMaDMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8vWCTm3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3FEVVRBm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oulMZPEN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lHmbUwMg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DvqsNxTW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sPj02zi8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DfqrJIdB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e1jUjEW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_869t9b5s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PFUZ9V6j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_STXiUMG5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zKrHk4m8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sme5eVY5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PejEc83y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_B4tW9PTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BUyqbSTD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rLM2nb0C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5R8JyFZr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H1k44n5b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZTcwI8iN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uPPqaBL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_emTQCa8D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZKpvHsj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jEaSJxJQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5PwN5ewR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dngVMMZc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XbrL1EJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4ZMo91sX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sjn87t3B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5BS5DAhU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DDRuhfox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GFGzVRaL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z9NjCTVG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1hBp4b0b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pxp8cFzU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mM1qXAZI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EmNiVX4A_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qniLSpyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aqhcZlfk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_OzYo5Q6b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_V5ga0cQ1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ooY6nm3p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_E5Pyiv79_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Gx7yREon_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_txNCtDop_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_RNubbMk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wtrPQj8E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WcvbLe51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LZxXKNT7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_aXEi7sDN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_muCXkArh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ycA31YYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W6WMRe25_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8VaE9ptH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cW2pImDd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TZ5iccAW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xqC45HBn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p6zKzh91_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8abCFcXU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aey6UjgV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CiDgQvg3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vPCHb7rQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0bcfvLTT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jRiyIi5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j9SPaDq6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Zl33L4ki_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GC1GkPvQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UF1XkjSs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tJr3EV1f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1Y3LytMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R7JBDAZD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s21sXv2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EitRZnw9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xFTncwBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9YDpkwR3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fDlmCEQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0mWxQULt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AcAJKdig_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iXQWFeS3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mnsNdhVH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_613mELo1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A5OyIWRW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NbuJXogb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Q9Hl9ERn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iD42JXI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8tM1EtnM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7Hy3qm7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_LOlrzvoX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CIje54ZL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_46nAH5TC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rahzf9UF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KJ7lPaRZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pNakre2q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VgVpOQ8j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9VFJFveN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w2YCbE93_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XrZg7lqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_znSJHgqM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SLtJbnG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IMcJCkNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BqNqldgm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0eKTBUxg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PXgiJle9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0OlDwjHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UBaa2ErJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P44BXKnt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aIBUG6os_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gq88cimK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6ebDItuo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iRWOff4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C1UxHs7P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eHMbFjJ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ozMktxgw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VIGBgIDU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OHTEX8xB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_F1xskjYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GhCbH83J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XAXKeGym_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8hSyycoF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kWa6Omp4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G0hBE6ZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VYxuisNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3VIpY2rJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5So1b9n3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DjVoanDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cm7cxPLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rXFfztfa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LnJe2Z3q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vwLnR9e1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lcCRucxt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7neoFJRq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6dSvbmMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rBshlD7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0XVoxk1A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tqtMaix1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_og5TLoeJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0avkbop4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ug7fCbC2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IpQKHnKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_sHWwyTLJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Ta2ZY7Hz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GhaHZjXx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fQuFe17O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1yWy1LxB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ugNMpHga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gpjbGk8s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qeLg7QDN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1GYbB1KS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nvuhOJqJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jKnAmhxM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HxCtXQPG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KAoLasOR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fFw8ed0n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gWxKflKj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LYGerc5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ffAo1rR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wHujtyac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PwP7F5wA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gtOexHJo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x23FIya0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vO7Qdc42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xSWNf3OK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_znmRIyGL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FzCTuK4o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gNqHv1R9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NMy8ahws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_c2pyu3j0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mtO9lkBZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GzXbHZSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7N22Eza6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sm2DNsaG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sV9Qz1uV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rjADMm9G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_vBoK2I0S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sQOjVxo4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PQGU8VtW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ccxRv5KD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SCgsEBHE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7SVjgLF0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qal3V0H2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RdFoHI91_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mbvNHAZl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HZXPAbk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kPHurJ1U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cTZe0PeD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LizjQaN0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aVCeod6t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jQGhI4iD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V8t5XZgi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e2Vt5E6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1XWmtF9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NRXJ9Gj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ajDxFSAX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x1HAZ9X1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qhCaVDus_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_maNPReQm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0oe23g2f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_y9xkJAuG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3raKgWaz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XmCKjE8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GW1odgNt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2wLL4bM2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ds302Q5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1c2KQjb4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lJpk5Omi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_40ZFxWqE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hgUqzAop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4f6f2PPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kshsFCO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u1QHxlK3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xi3kkCbR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GVrhc4Ue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CpsQ3o1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_erwPNI7t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l22efZVf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cdv4KLRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_njqoL8gY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NucHdNEE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Rl6xyMca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kzqxGMMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AOS0TzEa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4C0X6VJk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_voH9qp0f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZubdDSjG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_o0wAOYV0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GcT3rO3K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xMqw5Yrw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KApKPzux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_TnyRro4O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_el3dvNRO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pJJeu1ME_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bp8oOH6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t1niaNQB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O6CwOfQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HLTWVOcf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HcHlX8cW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hMahuvZT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WKh9vMLk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0ViuAySB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XhJVaLjN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pb4QvjbI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jmamyo4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ROq7Ke4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lwr8e8Z0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BPRriYxV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IQj1meRz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dId9RsGo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OhgR7au6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Kp8DDLAh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UuQlwP50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YrNzxWBx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Jt3IBeTm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IA0K7no5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_In9XPLdj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_71XABWSG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VCPmxn77_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s1Uefrbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qyvT6RHE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wK0zTHyM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ztZBUSYr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oqq03jJt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yTQOCaNk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RCDSjiXz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FkjBet8E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jIudkF8T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A81XK2Aa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WvT6gogf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KypuKS2u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9p9viJek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kmrHrzKi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f4oIEQWC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HO7cOPNL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_15ENubjV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GEu519xc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BDYAbTXE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Wk5UwxWA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hKzh2Wow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R0X6u1J2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZIvb1dqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0BTY3XRs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cCM5e95m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uvws5am0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BquMtFgB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KsKQulvG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lsxpQhyw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Un4Nnjw7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8Hz4ojMK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LKxnoQbW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4K88w7FT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dBGs0kAB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_msRlHn5W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wRMlHKSQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SyV7c93i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kbNyJ1Ka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7wfGx65g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a0cCNMP1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zNAUYq1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_f1iB4iws_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_9hfac1ea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2gJt4OU5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9hfurKMM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_A9nOt0v5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_npI6H1c8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oj6s5xCy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nzencNmi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fL10RYIh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_WrbOwLhx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_91cfFI19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yzAgjKnM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rAb3TcOe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_pH1FVXXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9tuhUBVK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_wz1i1xhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5jDO12AA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lBRaVaEz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UXLm2scv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Eh30GOC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FVnbbSN4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xh0MNXID_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_k648PPdf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_uer4TQKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8RbISRw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RUWmqGvM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qgL9toTb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wbqmvSLg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QHuERylh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jP9ZmtdP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TdhHP1Tj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Gy9KB9A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i1txQlrL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8Pl1xu0H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TD1N5xdy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9aaFIi2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aBu7nU74_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8zFQ2gKR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ausvgq6D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3rDoHPJe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CnoIjT4p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BVtRbT5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D5ircQ70_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eGcordOx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nRVzqbQK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9lH5NdJI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8XRmuHWv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7utqotWt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wJU9Ogpc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Dcs987zf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_XVnveQzq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CZpPG2Zh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CCQ2Qs8u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OypRlfJA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jeiOeF02_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I2MyVZAH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lN1lglCv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZeteZlTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9CIdyNYB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b2lKRIGZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V4IWAgjr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V0koRUlI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2sVbGwuo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8p1APkWT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JSSruxcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Drfx1QMB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ikc33e2B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lIdV5CsQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l74BsERR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QlIZB5p4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LEzDgIqD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jO5SbQZq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uUDDL8wq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aZ3ex8fA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gk6QG6Ld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bHDjWwlm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8cscXeZf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6ewwZG04_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VDjVn0Qr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_iorKR9Gr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2h30cIPx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lGB3LUIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TEiXJQes_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QThOAIMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vNkK16Hw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IaA8PWiA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GojoKYFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_u2b2qRqE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qc4aD7r5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1bN1jVv2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2jAoknbE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lND2oTK6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OwU8k4n7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kWw1P6zx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7tMIwe4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_832IMrnZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jJoD6gA4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_v5JlgsrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MX4g5vNQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BAneZezp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xYEPO18E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HHQSDeES_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UsrVXZTJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Xmovaknn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YZpZeFy3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7TZimP0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yVqSpp7d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U82vo58l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z1pUU368_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OrhMNgW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MVeSSN61_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QgMq1Cfo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JAxBqOFd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b9Pmonv1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6RttKGxO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bcBj7nka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HUeKwRnY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4nzieyUl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hCnlCoOg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6hEEYTmk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZOu4Uujm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tRkgahBS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HbFw8MEV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vAcvbNBg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yDK01CNr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OfSXvY8T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OlRomm92_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3yn7CLkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1oONsrkf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JeK8pN9B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_cJd8cIjR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mo1g5vdt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aVe37Wvg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gs8j1WXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ijIqsxqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lFAZHB8z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_8dO7KwyQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2OX6PtkY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QARaYfHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vvNh4VFC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lHDyrT7w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZgHIHNXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H1gEo1o0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iBFAtqpl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PaA6qvSH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3VRiPPsD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5A9GWeqG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6ugWQ5v3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3Cgz7pjX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nnpqhkwb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_udtZgNyf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HZYxjiPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pLcAT5uo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZRMs61P2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_a6VyYyPF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RH7QeR1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3IFZhRXy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1wMLdu7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P58k0gPN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tSQJHKGQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9tySZewX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pAcdHgvN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3DP5nY3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xOuXv2Pg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dpHvFnWd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IibHLrYa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iTiFwi3W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bUp9pZI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8zSSzHco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZJqQ17nr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2NM5qa5a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lyUQSu49_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zHCGltPm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0Y4vzU90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MVqTc8Ie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Resrhw4a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FyvEuw55_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HCeBtMhE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iL5L7E82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zrPrClRi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z9999lDQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZrxRVo9V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tBofFD1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WD6hgB2C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_znY8UY0p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AWInLBJW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m6blVPyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MFATBjh6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ErGEJiKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QnPIEOVX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2bmr7pu4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KjOp4hyO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qbTieCyk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eGz8kHnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YWtIw7s7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DL8Xbod5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GdiKkrtT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_UoGo7KOO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IunQJDsG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wiDATRB6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dT4ODTKi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pa8Kpn4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zpSeh4zV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LOi6FqlE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ETPb0BqS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g9RhyM1v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rYb9BU0W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_943bUim3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FfwWXuUV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_U0V4Ekui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1UdX3PTW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_K6jwdQhw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PrRFGB9H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_x04G0pcF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RP79Hr9B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nIP2aPSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dL2CdiDD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_U0Rgcfrv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0LF2JA9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6LL9mpAK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UIlOJ8Zf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6V1hFYDH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dlDwM6xD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zEdrQnEL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_b9P8fxx1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_93T7PDWy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7bTsuScr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0MLoNGvw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_C08YvRR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_126za1dg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ykr1ZJ5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LlInkqfs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_n48RdCIG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gpGpVDrN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lLxtQnRa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fbeqbJtq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jPgZgoYN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_stsn3JCQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_C7YXGuiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RC1STGN5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VvNgBcDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AxolXX30_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_RRIEAxdA;
  SignalLine sLine_OYRv3L6z;
  SignalLine sLine_R9R1C9Gq;
  SignalLine sLine_YhlfLYDc;
  SignalLine sLine_I2xfgYvA;
  SignalBiquad sBiquad_s_8vjDc1tO;
  SignalLine sLine_b9nzQLOC;
  SignalLine sLine_7eI8003V;
  SignalLine sLine_mqsVxGIM;
  SignalLine sLine_imf7U8AG;
  SignalBiquad sBiquad_s_8HcvDoDq;
  SignalLine sLine_bJ9pk6LC;
  SignalLine sLine_8ShhiqkY;
  SignalLine sLine_QKJL6KuX;
  SignalLine sLine_A81ewwIk;
  SignalLine sLine_NmWdnYyF;
  SignalBiquad sBiquad_s_mMvczGl6;
  SignalLine sLine_qmpdT7kh;
  SignalLine sLine_FouHN0Ke;
  SignalLine sLine_hKOJzvIV;
  SignalLine sLine_WHOIihFM;
  SignalLine sLine_Bp1CWXR4;
  SignalBiquad sBiquad_s_oQM06tDZ;
  SignalLine sLine_XHo7CS2B;
  SignalLine sLine_d7TnzUau;
  SignalLine sLine_8x0yBeXT;
  SignalLine sLine_b0pdyTk1;
  SignalBiquad sBiquad_s_Nbjuwmjk;
  SignalLine sLine_2PrwNZRW;
  SignalLine sLine_5SZz1qwR;
  SignalLine sLine_7xhp22u2;
  SignalLine sLine_V3kAG9EL;
  SignalLine sLine_oeLL4ZJa;
  SignalBiquad sBiquad_s_T4dDZckt;
  ControlVar cVar_niRulR8a;
  ControlVar cVar_5v68Tw5P;
  ControlVar cVar_5sjXZoMv;
  ControlVar cVar_AA2T9yvy;
  ControlSlice cSlice_1p2v0Iiz;
  ControlVar cVar_VlZKe685;
  ControlVar cVar_Yzixk9P4;
  ControlIf cIf_SexYL7PY;
  ControlIf cIf_eMVieUuE;
  ControlBinop cBinop_VsS7hbDO;
  ControlBinop cBinop_kU4AOwwG;
  ControlBinop cBinop_c1CHny1k;
  ControlBinop cBinop_bwqUGoMC;
  ControlBinop cBinop_8YkPr3EK;
  ControlIf cIf_wtLJ3uvm;
  ControlBinop cBinop_pT7eY0i1;
  ControlBinop cBinop_lOvCLwdJ;
  ControlBinop cBinop_Ue1kpWly;
  ControlBinop cBinop_74saEJam;
  ControlBinop cBinop_WqfW0QPN;
  ControlVar cVar_T7wG9dcQ;
  ControlIf cIf_VRQtpbfb;
  ControlIf cIf_41Uhi6Tf;
  ControlBinop cBinop_XkD49HHE;
  ControlBinop cBinop_vxJ9ggSU;
  ControlBinop cBinop_wIo2DTPV;
  ControlBinop cBinop_9m6KjFOq;
  ControlBinop cBinop_8vWCTm3j;
  ControlIf cIf_3FEVVRBm;
  ControlBinop cBinop_oulMZPEN;
  ControlBinop cBinop_lHmbUwMg;
  ControlBinop cBinop_sPj02zi8;
  ControlBinop cBinop_DfqrJIdB;
  ControlBinop cBinop_e1jUjEW6;
  ControlVar cVar_sme5eVY5;
  ControlIf cIf_PejEc83y;
  ControlIf cIf_B4tW9PTw;
  ControlBinop cBinop_rLM2nb0C;
  ControlBinop cBinop_5R8JyFZr;
  ControlBinop cBinop_uPPqaBL3;
  ControlBinop cBinop_emTQCa8D;
  ControlBinop cBinop_jEaSJxJQ;
  ControlIf cIf_5PwN5ewR;
  ControlBinop cBinop_dngVMMZc;
  ControlBinop cBinop_XbrL1EJB;
  ControlBinop cBinop_sjn87t3B;
  ControlBinop cBinop_5BS5DAhU;
  ControlBinop cBinop_DDRuhfox;
  ControlIf cIf_mM1qXAZI;
  ControlSlice cSlice_qniLSpyP;
  ControlVar cVar_aqhcZlfk;
  ControlSlice cSlice_ooY6nm3p;
  ControlVar cVar_E5Pyiv79;
  ControlSlice cSlice_RNubbMk8;
  ControlVar cVar_wtrPQj8E;
  ControlSlice cSlice_aXEi7sDN;
  ControlVar cVar_muCXkArh;
  ControlBinop cBinop_vPCHb7rQ;
  ControlBinop cBinop_jRiyIi5l;
  ControlBinop cBinop_j9SPaDq6;
  ControlBinop cBinop_UF1XkjSs;
  ControlBinop cBinop_tJr3EV1f;
  ControlBinop cBinop_1Y3LytMy;
  ControlBinop cBinop_R7JBDAZD;
  ControlBinop cBinop_s21sXv2m;
  ControlVar cVar_EitRZnw9;
  ControlBinop cBinop_xFTncwBl;
  ControlBinop cBinop_9YDpkwR3;
  ControlBinop cBinop_fDlmCEQL;
  ControlBinop cBinop_0mWxQULt;
  ControlBinop cBinop_AcAJKdig;
  ControlBinop cBinop_iXQWFeS3;
  ControlBinop cBinop_mnsNdhVH;
  ControlBinop cBinop_A5OyIWRW;
  ControlVar cVar_NbuJXogb;
  ControlVar cVar_Q9Hl9ERn;
  ControlBinop cBinop_rahzf9UF;
  ControlBinop cBinop_KJ7lPaRZ;
  ControlBinop cBinop_pNakre2q;
  ControlBinop cBinop_9VFJFveN;
  ControlBinop cBinop_w2YCbE93;
  ControlBinop cBinop_XrZg7lqt;
  ControlBinop cBinop_znSJHgqM;
  ControlBinop cBinop_SLtJbnG9;
  ControlBinop cBinop_IMcJCkNa;
  ControlBinop cBinop_8hSyycoF;
  ControlBinop cBinop_G0hBE6ZX;
  ControlBinop cBinop_VYxuisNH;
  ControlBinop cBinop_DjVoanDP;
  ControlBinop cBinop_Cm7cxPLq;
  ControlBinop cBinop_rXFfztfa;
  ControlBinop cBinop_LnJe2Z3q;
  ControlBinop cBinop_vwLnR9e1;
  ControlBinop cBinop_lcCRucxt;
  ControlBinop cBinop_7neoFJRq;
  ControlBinop cBinop_rBshlD7G;
  ControlVar cVar_0XVoxk1A;
  ControlVar cVar_tqtMaix1;
  ControlVar cVar_og5TLoeJ;
  ControlBinop cBinop_fQuFe17O;
  ControlBinop cBinop_1yWy1LxB;
  ControlBinop cBinop_ugNMpHga;
  ControlBinop cBinop_qeLg7QDN;
  ControlBinop cBinop_1GYbB1KS;
  ControlBinop cBinop_nvuhOJqJ;
  ControlBinop cBinop_jKnAmhxM;
  ControlBinop cBinop_HxCtXQPG;
  ControlBinop cBinop_GzXbHZSP;
  ControlBinop cBinop_sm2DNsaG;
  ControlBinop cBinop_sV9Qz1uV;
  ControlBinop cBinop_sQOjVxo4;
  ControlBinop cBinop_PQGU8VtW;
  ControlBinop cBinop_ccxRv5KD;
  ControlBinop cBinop_SCgsEBHE;
  ControlBinop cBinop_7SVjgLF0;
  ControlBinop cBinop_RdFoHI91;
  ControlBinop cBinop_HZXPAbk8;
  ControlBinop cBinop_kPHurJ1U;
  ControlBinop cBinop_LizjQaN0;
  ControlBinop cBinop_aVCeod6t;
  ControlBinop cBinop_jQGhI4iD;
  ControlBinop cBinop_e2Vt5E6S;
  ControlVar cVar_1XWmtF9t;
  ControlVar cVar_NRXJ9Gj8;
  ControlVar cVar_ajDxFSAX;
  ControlBinop cBinop_XmCKjE8Z;
  ControlBinop cBinop_GW1odgNt;
  ControlBinop cBinop_2wLL4bM2;
  ControlBinop cBinop_1c2KQjb4;
  ControlBinop cBinop_lJpk5Omi;
  ControlBinop cBinop_40ZFxWqE;
  ControlBinop cBinop_hgUqzAop;
  ControlBinop cBinop_4f6f2PPw;
  ControlBinop cBinop_kshsFCO0;
  ControlBinop cBinop_kzqxGMMA;
  ControlBinop cBinop_4C0X6VJk;
  ControlBinop cBinop_voH9qp0f;
  SignalVarf sVarf_pdiz2DWB;
  SignalVarf sVarf_keYfOPKk;
  SignalVarf sVarf_oNOJwrPb;
  ControlSlice cSlice_o0wAOYV0;
  ControlVar cVar_GcT3rO3K;
  ControlVar cVar_KApKPzux;
  ControlIf cIf_TnyRro4O;
  ControlIf cIf_el3dvNRO;
  ControlBinop cBinop_Bp8oOH6S;
  ControlBinop cBinop_t1niaNQB;
  ControlBinop cBinop_HcHlX8cW;
  ControlBinop cBinop_hMahuvZT;
  ControlBinop cBinop_0ViuAySB;
  ControlIf cIf_XhJVaLjN;
  ControlBinop cBinop_pb4QvjbI;
  ControlBinop cBinop_jmamyo4W;
  ControlBinop cBinop_Lwr8e8Z0;
  ControlBinop cBinop_BPRriYxV;
  ControlBinop cBinop_IQj1meRz;
  ControlVar cVar_YrNzxWBx;
  ControlIf cIf_Jt3IBeTm;
  ControlIf cIf_IA0K7no5;
  ControlBinop cBinop_71XABWSG;
  ControlBinop cBinop_VCPmxn77;
  ControlBinop cBinop_wK0zTHyM;
  ControlBinop cBinop_ztZBUSYr;
  ControlBinop cBinop_yTQOCaNk;
  ControlIf cIf_RCDSjiXz;
  ControlBinop cBinop_FkjBet8E;
  ControlBinop cBinop_jIudkF8T;
  ControlBinop cBinop_WvT6gogf;
  ControlBinop cBinop_KypuKS2u;
  ControlBinop cBinop_9p9viJek;
  ControlVar cVar_GEu519xc;
  ControlIf cIf_BDYAbTXE;
  ControlIf cIf_Wk5UwxWA;
  ControlBinop cBinop_R0X6u1J2;
  ControlBinop cBinop_ZIvb1dqz;
  ControlBinop cBinop_Uvws5am0;
  ControlBinop cBinop_BquMtFgB;
  ControlBinop cBinop_lsxpQhyw;
  ControlIf cIf_Un4Nnjw7;
  ControlBinop cBinop_8Hz4ojMK;
  ControlBinop cBinop_LKxnoQbW;
  ControlBinop cBinop_dBGs0kAB;
  ControlBinop cBinop_msRlHn5W;
  ControlBinop cBinop_wRMlHKSQ;
  ControlIf cIf_zNAUYq1z;
  ControlSlice cSlice_9hfac1ea;
  ControlVar cVar_2gJt4OU5;
  ControlSlice cSlice_npI6H1c8;
  ControlVar cVar_oj6s5xCy;
  ControlSlice cSlice_WrbOwLhx;
  ControlVar cVar_91cfFI19;
  ControlSlice cSlice_pH1FVXXo;
  ControlVar cVar_9tuhUBVK;
  ControlBinop cBinop_RUWmqGvM;
  ControlBinop cBinop_wbqmvSLg;
  ControlBinop cBinop_QHuERylh;
  ControlBinop cBinop_9Gy9KB9A;
  ControlBinop cBinop_i1txQlrL;
  ControlBinop cBinop_8Pl1xu0H;
  ControlBinop cBinop_TD1N5xdy;
  ControlBinop cBinop_9aaFIi2g;
  ControlVar cVar_aBu7nU74;
  ControlBinop cBinop_8zFQ2gKR;
  ControlBinop cBinop_Ausvgq6D;
  ControlBinop cBinop_3rDoHPJe;
  ControlBinop cBinop_CnoIjT4p;
  ControlBinop cBinop_BVtRbT5M;
  ControlBinop cBinop_D5ircQ70;
  ControlBinop cBinop_eGcordOx;
  ControlBinop cBinop_9lH5NdJI;
  ControlVar cVar_8XRmuHWv;
  ControlVar cVar_7utqotWt;
  ControlBinop cBinop_jeiOeF02;
  ControlBinop cBinop_I2MyVZAH;
  ControlBinop cBinop_lN1lglCv;
  ControlBinop cBinop_9CIdyNYB;
  ControlBinop cBinop_b2lKRIGZ;
  ControlBinop cBinop_V4IWAgjr;
  ControlBinop cBinop_V0koRUlI;
  ControlBinop cBinop_2sVbGwuo;
  ControlBinop cBinop_8p1APkWT;
  ControlBinop cBinop_TEiXJQes;
  ControlBinop cBinop_vNkK16Hw;
  ControlBinop cBinop_IaA8PWiA;
  ControlBinop cBinop_Qc4aD7r5;
  ControlBinop cBinop_1bN1jVv2;
  ControlBinop cBinop_2jAoknbE;
  ControlBinop cBinop_lND2oTK6;
  ControlBinop cBinop_OwU8k4n7;
  ControlBinop cBinop_kWw1P6zx;
  ControlBinop cBinop_7tMIwe4q;
  ControlBinop cBinop_jJoD6gA4;
  ControlVar cVar_v5JlgsrJ;
  ControlVar cVar_MX4g5vNQ;
  ControlVar cVar_BAneZezp;
  ControlBinop cBinop_yVqSpp7d;
  ControlBinop cBinop_U82vo58l;
  ControlBinop cBinop_z1pUU368;
  ControlBinop cBinop_MVeSSN61;
  ControlBinop cBinop_QgMq1Cfo;
  ControlBinop cBinop_JAxBqOFd;
  ControlBinop cBinop_b9Pmonv1;
  ControlBinop cBinop_6RttKGxO;
  ControlBinop cBinop_aVe37Wvg;
  ControlBinop cBinop_ijIqsxqq;
  ControlBinop cBinop_lFAZHB8z;
  ControlBinop cBinop_QARaYfHD;
  ControlBinop cBinop_vvNh4VFC;
  ControlBinop cBinop_lHDyrT7w;
  ControlBinop cBinop_ZgHIHNXd;
  ControlBinop cBinop_H1gEo1o0;
  ControlBinop cBinop_PaA6qvSH;
  ControlBinop cBinop_5A9GWeqG;
  ControlBinop cBinop_6ugWQ5v3;
  ControlBinop cBinop_Nnpqhkwb;
  ControlBinop cBinop_udtZgNyf;
  ControlBinop cBinop_HZYxjiPr;
  ControlBinop cBinop_ZRMs61P2;
  ControlVar cVar_a6VyYyPF;
  ControlVar cVar_RH7QeR1s;
  ControlVar cVar_3IFZhRXy;
  ControlBinop cBinop_xOuXv2Pg;
  ControlBinop cBinop_dpHvFnWd;
  ControlBinop cBinop_IibHLrYa;
  ControlBinop cBinop_bUp9pZI2;
  ControlBinop cBinop_8zSSzHco;
  ControlBinop cBinop_ZJqQ17nr;
  ControlBinop cBinop_2NM5qa5a;
  ControlBinop cBinop_lyUQSu49;
  ControlBinop cBinop_zHCGltPm;
  ControlBinop cBinop_WD6hgB2C;
  ControlBinop cBinop_AWInLBJW;
  ControlBinop cBinop_m6blVPyH;
  SignalVarf sVarf_94IAxaPE;
  SignalVarf sVarf_Xb4vVoad;
  SignalVarf sVarf_Ef3Mx02W;
  ControlVar cVar_MFATBjh6;
  ControlVar cVar_ErGEJiKc;
  ControlBinop cBinop_YWtIw7s7;
  ControlBinop cBinop_DL8Xbod5;
  ControlBinop cBinop_GdiKkrtT;
  ControlBinop cBinop_IunQJDsG;
  ControlBinop cBinop_wiDATRB6;
  ControlBinop cBinop_dT4ODTKi;
  ControlBinop cBinop_Pa8Kpn4M;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
