/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_RRIEAxdA);
  numBytes += sLine_init(&sLine_OYRv3L6z);
  numBytes += sLine_init(&sLine_R9R1C9Gq);
  numBytes += sLine_init(&sLine_YhlfLYDc);
  numBytes += sLine_init(&sLine_I2xfgYvA);
  numBytes += sBiquad_init(&sBiquad_s_8vjDc1tO);
  numBytes += sLine_init(&sLine_b9nzQLOC);
  numBytes += sLine_init(&sLine_7eI8003V);
  numBytes += sLine_init(&sLine_mqsVxGIM);
  numBytes += sLine_init(&sLine_imf7U8AG);
  numBytes += sBiquad_init(&sBiquad_s_8HcvDoDq);
  numBytes += sLine_init(&sLine_bJ9pk6LC);
  numBytes += sLine_init(&sLine_8ShhiqkY);
  numBytes += sLine_init(&sLine_QKJL6KuX);
  numBytes += sLine_init(&sLine_A81ewwIk);
  numBytes += sLine_init(&sLine_NmWdnYyF);
  numBytes += sBiquad_init(&sBiquad_s_mMvczGl6);
  numBytes += sLine_init(&sLine_qmpdT7kh);
  numBytes += sLine_init(&sLine_FouHN0Ke);
  numBytes += sLine_init(&sLine_hKOJzvIV);
  numBytes += sLine_init(&sLine_WHOIihFM);
  numBytes += sLine_init(&sLine_Bp1CWXR4);
  numBytes += sBiquad_init(&sBiquad_s_oQM06tDZ);
  numBytes += sLine_init(&sLine_XHo7CS2B);
  numBytes += sLine_init(&sLine_d7TnzUau);
  numBytes += sLine_init(&sLine_8x0yBeXT);
  numBytes += sLine_init(&sLine_b0pdyTk1);
  numBytes += sBiquad_init(&sBiquad_s_Nbjuwmjk);
  numBytes += sLine_init(&sLine_2PrwNZRW);
  numBytes += sLine_init(&sLine_5SZz1qwR);
  numBytes += sLine_init(&sLine_7xhp22u2);
  numBytes += sLine_init(&sLine_V3kAG9EL);
  numBytes += sLine_init(&sLine_oeLL4ZJa);
  numBytes += sBiquad_init(&sBiquad_s_T4dDZckt);
  numBytes += cVar_init_f(&cVar_niRulR8a, 0.0f);
  numBytes += cVar_init_f(&cVar_5v68Tw5P, 0.0f);
  numBytes += cVar_init_f(&cVar_5sjXZoMv, 0.0f);
  numBytes += cVar_init_f(&cVar_AA2T9yvy, 0.0f);
  numBytes += cSlice_init(&cSlice_1p2v0Iiz, 1, -1);
  numBytes += cVar_init_f(&cVar_VlZKe685, 1337.0f);
  numBytes += cVar_init_f(&cVar_Yzixk9P4, 0.0f);
  numBytes += cIf_init(&cIf_SexYL7PY, false);
  numBytes += cIf_init(&cIf_eMVieUuE, false);
  numBytes += cBinop_init(&cBinop_VsS7hbDO, 0.0f); // __pow
  numBytes += cIf_init(&cIf_wtLJ3uvm, false);
  numBytes += cBinop_init(&cBinop_Ue1kpWly, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_74saEJam, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_WqfW0QPN, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_T7wG9dcQ, 0.0f);
  numBytes += cIf_init(&cIf_VRQtpbfb, false);
  numBytes += cIf_init(&cIf_41Uhi6Tf, false);
  numBytes += cBinop_init(&cBinop_XkD49HHE, 0.0f); // __pow
  numBytes += cIf_init(&cIf_3FEVVRBm, false);
  numBytes += cBinop_init(&cBinop_sPj02zi8, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_DfqrJIdB, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_e1jUjEW6, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_sme5eVY5, 0.0f);
  numBytes += cIf_init(&cIf_PejEc83y, false);
  numBytes += cIf_init(&cIf_B4tW9PTw, false);
  numBytes += cBinop_init(&cBinop_rLM2nb0C, 0.0f); // __pow
  numBytes += cIf_init(&cIf_5PwN5ewR, false);
  numBytes += cBinop_init(&cBinop_sjn87t3B, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_5BS5DAhU, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_DDRuhfox, -15.0f); // __eq
  numBytes += cIf_init(&cIf_mM1qXAZI, false);
  numBytes += cSlice_init(&cSlice_qniLSpyP, 1, -1);
  numBytes += cVar_init_f(&cVar_aqhcZlfk, 0.0f);
  numBytes += cSlice_init(&cSlice_ooY6nm3p, 1, -1);
  numBytes += cVar_init_f(&cVar_E5Pyiv79, 0.0f);
  numBytes += cSlice_init(&cSlice_RNubbMk8, 1, -1);
  numBytes += cVar_init_f(&cVar_wtrPQj8E, 0.0f);
  numBytes += cSlice_init(&cSlice_aXEi7sDN, 1, -1);
  numBytes += cVar_init_f(&cVar_muCXkArh, 0.313f);
  numBytes += cBinop_init(&cBinop_jRiyIi5l, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_j9SPaDq6, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_EitRZnw9, 0.0f);
  numBytes += cVar_init_f(&cVar_NbuJXogb, 1337.0f);
  numBytes += cVar_init_f(&cVar_Q9Hl9ERn, 0.3f);
  numBytes += cBinop_init(&cBinop_KJ7lPaRZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_w2YCbE93, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XrZg7lqt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_znSJHgqM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SLtJbnG9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IMcJCkNa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_G0hBE6ZX, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_VYxuisNH, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_0XVoxk1A, 0.0f);
  numBytes += cVar_init_f(&cVar_tqtMaix1, 1337.0f);
  numBytes += cVar_init_f(&cVar_og5TLoeJ, 0.313f);
  numBytes += cBinop_init(&cBinop_1yWy1LxB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1GYbB1KS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nvuhOJqJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jKnAmhxM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HxCtXQPG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sm2DNsaG, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_sV9Qz1uV, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_1XWmtF9t, 0.0f);
  numBytes += cVar_init_f(&cVar_NRXJ9Gj8, 1037.0f);
  numBytes += cVar_init_f(&cVar_ajDxFSAX, 0.4f);
  numBytes += cBinop_init(&cBinop_GW1odgNt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lJpk5Omi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_40ZFxWqE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hgUqzAop, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4f6f2PPw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kshsFCO0, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_pdiz2DWB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_keYfOPKk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oNOJwrPb, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_o0wAOYV0, 1, -1);
  numBytes += cVar_init_f(&cVar_GcT3rO3K, 1337.0f);
  numBytes += cVar_init_f(&cVar_KApKPzux, 0.0f);
  numBytes += cIf_init(&cIf_TnyRro4O, false);
  numBytes += cIf_init(&cIf_el3dvNRO, false);
  numBytes += cBinop_init(&cBinop_Bp8oOH6S, 0.0f); // __pow
  numBytes += cIf_init(&cIf_XhJVaLjN, false);
  numBytes += cBinop_init(&cBinop_Lwr8e8Z0, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_BPRriYxV, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_IQj1meRz, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_YrNzxWBx, 0.0f);
  numBytes += cIf_init(&cIf_Jt3IBeTm, false);
  numBytes += cIf_init(&cIf_IA0K7no5, false);
  numBytes += cBinop_init(&cBinop_71XABWSG, 0.0f); // __pow
  numBytes += cIf_init(&cIf_RCDSjiXz, false);
  numBytes += cBinop_init(&cBinop_WvT6gogf, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_KypuKS2u, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_9p9viJek, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_GEu519xc, 0.0f);
  numBytes += cIf_init(&cIf_BDYAbTXE, false);
  numBytes += cIf_init(&cIf_Wk5UwxWA, false);
  numBytes += cBinop_init(&cBinop_R0X6u1J2, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Un4Nnjw7, false);
  numBytes += cBinop_init(&cBinop_dBGs0kAB, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_msRlHn5W, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_wRMlHKSQ, -15.0f); // __eq
  numBytes += cIf_init(&cIf_zNAUYq1z, false);
  numBytes += cSlice_init(&cSlice_9hfac1ea, 1, -1);
  numBytes += cVar_init_f(&cVar_2gJt4OU5, 0.0f);
  numBytes += cSlice_init(&cSlice_npI6H1c8, 1, -1);
  numBytes += cVar_init_f(&cVar_oj6s5xCy, 0.0f);
  numBytes += cSlice_init(&cSlice_WrbOwLhx, 1, -1);
  numBytes += cVar_init_f(&cVar_91cfFI19, 0.0f);
  numBytes += cSlice_init(&cSlice_pH1FVXXo, 1, -1);
  numBytes += cVar_init_f(&cVar_9tuhUBVK, 0.313f);
  numBytes += cBinop_init(&cBinop_wbqmvSLg, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_QHuERylh, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_aBu7nU74, 0.0f);
  numBytes += cVar_init_f(&cVar_8XRmuHWv, 1337.0f);
  numBytes += cVar_init_f(&cVar_7utqotWt, 0.3f);
  numBytes += cBinop_init(&cBinop_I2MyVZAH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_b2lKRIGZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_V4IWAgjr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_V0koRUlI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2sVbGwuo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8p1APkWT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vNkK16Hw, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_IaA8PWiA, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_v5JlgsrJ, 0.0f);
  numBytes += cVar_init_f(&cVar_MX4g5vNQ, 1337.0f);
  numBytes += cVar_init_f(&cVar_BAneZezp, 0.313f);
  numBytes += cBinop_init(&cBinop_U82vo58l, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QgMq1Cfo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JAxBqOFd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_b9Pmonv1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6RttKGxO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ijIqsxqq, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_lFAZHB8z, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_a6VyYyPF, 0.0f);
  numBytes += cVar_init_f(&cVar_RH7QeR1s, 1037.0f);
  numBytes += cVar_init_f(&cVar_3IFZhRXy, 0.4f);
  numBytes += cBinop_init(&cBinop_dpHvFnWd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8zSSzHco, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZJqQ17nr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2NM5qa5a, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lyUQSu49, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zHCGltPm, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_94IAxaPE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Xb4vVoad, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ef3Mx02W, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MFATBjh6, 5705.6f);
  numBytes += cVar_init_f(&cVar_ErGEJiKc, 313.3f);
  numBytes += cBinop_init(&cBinop_YWtIw7s7, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_DL8Xbod5, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_GdiKkrtT, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U0V4Ekui_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K6jwdQhw_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1UdX3PTW_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AxolXX30_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RP79Hr9B_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nIP2aPSK_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PrRFGB9H_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x04G0pcF_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dL2CdiDD_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UIlOJ8Zf_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6LL9mpAK_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0LF2JA9Y_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zEdrQnEL_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dlDwM6xD_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6V1hFYDH_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7bTsuScr_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_93T7PDWy_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b9P8fxx1_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_126za1dg_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ykr1ZJ5g_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0MLoNGvw_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C08YvRR1_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LlInkqfs_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lLxtQnRa_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gpGpVDrN_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n48RdCIG_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_stsn3JCQ_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jPgZgoYN_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fbeqbJtq_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VvNgBcDy_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RC1STGN5_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C7YXGuiD_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U0Rgcfrv_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_niRulR8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zpSeh4zV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_5v68Tw5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LOi6FqlE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_5sjXZoMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ETPb0BqS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_AA2T9yvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g9RhyM1v_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eGz8kHnF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qbTieCyk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KjOp4hyO_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_BbkifwyV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1p2v0Iiz, 0, m, &cSlice_1p2v0Iiz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_txNCtDop_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_1p2v0Iiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_K9l9WH5j_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_K9l9WH5j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_VlZKe685_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_K9l9WH5j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_K9l9WH5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PrRFGB9H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Yzixk9P4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pT7eY0i1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_SexYL7PY, 0, m, &cIf_SexYL7PY_sendMessage);
}

void Heavy_WSTD_3Q::cIf_SexYL7PY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lOvCLwdJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_eMVieUuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_9swCzRyR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_bwqUGoMC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_cphR5aWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VsS7hbDO, HV_BINOP_POW, 0, m, &cBinop_VsS7hbDO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VsS7hbDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wtLJ3uvm, 0, m, &cIf_wtLJ3uvm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kU4AOwwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_8YkPr3EK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZaWML1me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_c1CHny1k_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FLv7VHuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eMVieUuE, 0, m, &cIf_eMVieUuE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_c1CHny1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eMVieUuE, 1, m, &cIf_eMVieUuE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bwqUGoMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_kU4AOwwG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_9swCzRyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_wtLJ3uvm, 0, m, &cIf_wtLJ3uvm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8YkPr3EK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VsS7hbDO, HV_BINOP_POW, 1, m, &cBinop_VsS7hbDO_sendMessage);
  cMsg_cphR5aWd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_wtLJ3uvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_pdiz2DWB, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_pT7eY0i1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SexYL7PY, 1, m, &cIf_SexYL7PY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lOvCLwdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_74saEJam, HV_BINOP_GREATER_THAN, 1, m, &cBinop_74saEJam_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WqfW0QPN, HV_BINOP_EQ, 1, m, &cBinop_WqfW0QPN_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_8kSOsTSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ue1kpWly, HV_BINOP_ADD, 0, m, &cBinop_Ue1kpWly_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ue1kpWly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZaWML1me_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FLv7VHuf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_74saEJam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wtLJ3uvm, 1, m, &cIf_wtLJ3uvm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WqfW0QPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8cTZuJTY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_8cTZuJTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_pdiz2DWB, m);
}

void Heavy_WSTD_3Q::cCast_6J5lUQ2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Yzixk9P4, 0, m, &cVar_Yzixk9P4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1LSs9Dao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ue1kpWly, HV_BINOP_ADD, 1, m, &cBinop_Ue1kpWly_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_74saEJam, HV_BINOP_GREATER_THAN, 0, m, &cBinop_74saEJam_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WqfW0QPN, HV_BINOP_EQ, 0, m, &cBinop_WqfW0QPN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vwHoah1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8kSOsTSA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_T7wG9dcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oulMZPEN_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VRQtpbfb, 0, m, &cIf_VRQtpbfb_sendMessage);
}

void Heavy_WSTD_3Q::cIf_VRQtpbfb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lHmbUwMg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_41Uhi6Tf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_5DpMaDMP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_9m6KjFOq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_ZJRFx0kv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XkD49HHE, HV_BINOP_POW, 0, m, &cBinop_XkD49HHE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XkD49HHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3FEVVRBm, 0, m, &cIf_3FEVVRBm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vxJ9ggSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_8vWCTm3j_sendMessage);
}

void Heavy_WSTD_3Q::cCast_P9x06gvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_41Uhi6Tf, 0, m, &cIf_41Uhi6Tf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RoHJwdYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wIo2DTPV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wIo2DTPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_41Uhi6Tf, 1, m, &cIf_41Uhi6Tf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9m6KjFOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_vxJ9ggSU_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_5DpMaDMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_3FEVVRBm, 0, m, &cIf_3FEVVRBm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8vWCTm3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XkD49HHE, HV_BINOP_POW, 1, m, &cBinop_XkD49HHE_sendMessage);
  cMsg_ZJRFx0kv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_3FEVVRBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kzqxGMMA_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4C0X6VJk_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_voH9qp0f_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_oulMZPEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VRQtpbfb, 1, m, &cIf_VRQtpbfb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lHmbUwMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DfqrJIdB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_DfqrJIdB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_e1jUjEW6, HV_BINOP_EQ, 1, m, &cBinop_e1jUjEW6_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_DvqsNxTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sPj02zi8, HV_BINOP_ADD, 0, m, &cBinop_sPj02zi8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sPj02zi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RoHJwdYb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P9x06gvZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DfqrJIdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3FEVVRBm, 1, m, &cIf_3FEVVRBm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_e1jUjEW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_869t9b5s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_869t9b5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kzqxGMMA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4C0X6VJk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_voH9qp0f_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PFUZ9V6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DvqsNxTW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_STXiUMG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sPj02zi8, HV_BINOP_ADD, 1, m, &cBinop_sPj02zi8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DfqrJIdB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_DfqrJIdB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_e1jUjEW6, HV_BINOP_EQ, 0, m, &cBinop_e1jUjEW6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zKrHk4m8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T7wG9dcQ, 0, m, &cVar_T7wG9dcQ_sendMessage);
}

void Heavy_WSTD_3Q::cVar_sme5eVY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dngVMMZc_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_PejEc83y, 0, m, &cIf_PejEc83y_sendMessage);
}

void Heavy_WSTD_3Q::cIf_PejEc83y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XbrL1EJB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_B4tW9PTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ZKpvHsj1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_emTQCa8D_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_BUyqbSTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rLM2nb0C, HV_BINOP_POW, 0, m, &cBinop_rLM2nb0C_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rLM2nb0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5PwN5ewR, 0, m, &cIf_5PwN5ewR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5R8JyFZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_jEaSJxJQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_H1k44n5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uPPqaBL3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZTcwI8iN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B4tW9PTw, 0, m, &cIf_B4tW9PTw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uPPqaBL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B4tW9PTw, 1, m, &cIf_B4tW9PTw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_emTQCa8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_5R8JyFZr_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZKpvHsj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_5PwN5ewR, 0, m, &cIf_5PwN5ewR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jEaSJxJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rLM2nb0C, HV_BINOP_POW, 1, m, &cBinop_rLM2nb0C_sendMessage);
  cMsg_BUyqbSTD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_5PwN5ewR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_oNOJwrPb, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_dngVMMZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PejEc83y, 1, m, &cIf_PejEc83y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XbrL1EJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5BS5DAhU, HV_BINOP_GREATER_THAN, 1, m, &cBinop_5BS5DAhU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DDRuhfox, HV_BINOP_EQ, 1, m, &cBinop_DDRuhfox_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4ZMo91sX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sjn87t3B, HV_BINOP_ADD, 0, m, &cBinop_sjn87t3B_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sjn87t3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H1k44n5b_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZTcwI8iN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5BS5DAhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5PwN5ewR, 1, m, &cIf_5PwN5ewR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DDRuhfox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GFGzVRaL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_GFGzVRaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oNOJwrPb, m);
}

void Heavy_WSTD_3Q::cCast_z9NjCTVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sme5eVY5, 0, m, &cVar_sme5eVY5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1hBp4b0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4ZMo91sX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_pxp8cFzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sjn87t3B, HV_BINOP_ADD, 1, m, &cBinop_sjn87t3B_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5BS5DAhU, HV_BINOP_GREATER_THAN, 0, m, &cBinop_5BS5DAhU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DDRuhfox, HV_BINOP_EQ, 0, m, &cBinop_DDRuhfox_sendMessage);
}

void Heavy_WSTD_3Q::cIf_mM1qXAZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_keYfOPKk, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_EmNiVX4A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qniLSpyP, 0, m, &cSlice_qniLSpyP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_V5ga0cQ1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_qniLSpyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OzYo5Q6b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OzYo5Q6b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_aqhcZlfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OzYo5Q6b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_OzYo5Q6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RP79Hr9B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_V5ga0cQ1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ooY6nm3p, 0, m, &cSlice_ooY6nm3p_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BbkifwyV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_ooY6nm3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Gx7yREon_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Gx7yREon_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_E5Pyiv79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Gx7yREon_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Gx7yREon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dL2CdiDD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_txNCtDop_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RNubbMk8, 0, m, &cSlice_RNubbMk8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LZxXKNT7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_RNubbMk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WcvbLe51_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WcvbLe51_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_wtrPQj8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WcvbLe51_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_WcvbLe51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nIP2aPSK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_LZxXKNT7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aXEi7sDN, 0, m, &cSlice_aXEi7sDN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_aXEi7sDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ycA31YYn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ycA31YYn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_muCXkArh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ycA31YYn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ycA31YYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_x04G0pcF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_W6WMRe25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RRIEAxdA, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_8VaE9ptH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OYRv3L6z, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_cW2pImDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R9R1C9Gq, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_TZ5iccAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YhlfLYDc, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xqC45HBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I2xfgYvA, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_p6zKzh91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8abCFcXU_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_8abCFcXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jRiyIi5l, HV_BINOP_DIVIDE, 1, m, &cBinop_jRiyIi5l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0bcfvLTT_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_aey6UjgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_vPCHb7rQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_CiDgQvg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_aey6UjgV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vPCHb7rQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jRiyIi5l, HV_BINOP_DIVIDE, 0, m, &cBinop_jRiyIi5l_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0bcfvLTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CiDgQvg3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_jRiyIi5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j9SPaDq6, HV_BINOP_MULTIPLY, 1, m, &cBinop_j9SPaDq6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_j9SPaDq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iD42JXI1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8tM1EtnM_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Zl33L4ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7Hy3qm7C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_GC1GkPvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LOlrzvoX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UF1XkjSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_tJr3EV1f_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tJr3EV1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j9SPaDq6, HV_BINOP_MULTIPLY, 0, m, &cBinop_j9SPaDq6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1Y3LytMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_R7JBDAZD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_R7JBDAZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_46nAH5TC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_s21sXv2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EitRZnw9, 1, m, &cVar_EitRZnw9_sendMessage);
}

void Heavy_WSTD_3Q::cVar_EitRZnw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VgVpOQ8j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xFTncwBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w2YCbE93, HV_BINOP_MULTIPLY, 1, m, &cBinop_w2YCbE93_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9YDpkwR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xFTncwBl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fDlmCEQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0mWxQULt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0mWxQULt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XrZg7lqt, HV_BINOP_MULTIPLY, 1, m, &cBinop_XrZg7lqt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AcAJKdig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_znSJHgqM, HV_BINOP_MULTIPLY, 1, m, &cBinop_znSJHgqM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iXQWFeS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AcAJKdig_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mnsNdhVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SLtJbnG9, HV_BINOP_MULTIPLY, 1, m, &cBinop_SLtJbnG9_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_613mELo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_A5OyIWRW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_A5OyIWRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IMcJCkNa, HV_BINOP_MULTIPLY, 1, m, &cBinop_IMcJCkNa_sendMessage);
}

void Heavy_WSTD_3Q::cVar_NbuJXogb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iRWOff4q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_UF1XkjSs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6ebDItuo_sendMessage);
}

void Heavy_WSTD_3Q::cVar_Q9Hl9ERn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_1Y3LytMy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_iD42JXI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Zl33L4ki_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8tM1EtnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_GC1GkPvQ_sendMessage);
}

void Heavy_WSTD_3Q::cSend_7Hy3qm7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0LF2JA9Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_LOlrzvoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6LL9mpAK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_CIje54ZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UIlOJ8Zf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_46nAH5TC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rahzf9UF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rahzf9UF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KJ7lPaRZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_KJ7lPaRZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KJ7lPaRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pNakre2q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pNakre2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CIje54ZL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_VgVpOQ8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9VFJFveN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9VFJFveN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gq88cimK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UBaa2ErJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PXgiJle9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P44BXKnt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0OlDwjHd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIBUG6os_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_w2YCbE93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W6WMRe25_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_XrZg7lqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8VaE9ptH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_znSJHgqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cW2pImDd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SLtJbnG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TZ5iccAW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_IMcJCkNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xqC45HBn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_BqNqldgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NbuJXogb, 0, m, &cVar_NbuJXogb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0eKTBUxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q9Hl9ERn, 1, m, &cVar_Q9Hl9ERn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PXgiJle9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SLtJbnG9, HV_BINOP_MULTIPLY, 0, m, &cBinop_SLtJbnG9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0OlDwjHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XrZg7lqt, HV_BINOP_MULTIPLY, 0, m, &cBinop_XrZg7lqt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UBaa2ErJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IMcJCkNa, HV_BINOP_MULTIPLY, 0, m, &cBinop_IMcJCkNa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_P44BXKnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_znSJHgqM, HV_BINOP_MULTIPLY, 0, m, &cBinop_znSJHgqM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_aIBUG6os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w2YCbE93, HV_BINOP_MULTIPLY, 0, m, &cBinop_w2YCbE93_sendMessage);
}

void Heavy_WSTD_3Q::cCast_gq88cimK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_6ebDItuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EitRZnw9, 0, m, &cVar_EitRZnw9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_iRWOff4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q9Hl9ERn, 0, m, &cVar_Q9Hl9ERn_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_C1UxHs7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b9nzQLOC, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_eHMbFjJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7eI8003V, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ozMktxgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mqsVxGIM, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_VIGBgIDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_imf7U8AG, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_OHTEX8xB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_F1xskjYH_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_F1xskjYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G0hBE6ZX, HV_BINOP_DIVIDE, 1, m, &cBinop_G0hBE6ZX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kWa6Omp4_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_GhCbH83J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_8hSyycoF_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_XAXKeGym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_GhCbH83J_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8hSyycoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G0hBE6ZX, HV_BINOP_DIVIDE, 0, m, &cBinop_G0hBE6ZX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kWa6Omp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XAXKeGym_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_G0hBE6ZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VYxuisNH, HV_BINOP_MULTIPLY, 1, m, &cBinop_VYxuisNH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VYxuisNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ug7fCbC2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0avkbop4_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_3VIpY2rJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IpQKHnKN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_5So1b9n3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sHWwyTLJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_DjVoanDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Cm7cxPLq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Cm7cxPLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VYxuisNH, HV_BINOP_MULTIPLY, 0, m, &cBinop_VYxuisNH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rXFfztfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_LnJe2Z3q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LnJe2Z3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GhaHZjXx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_vwLnR9e1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nvuhOJqJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_nvuhOJqJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lcCRucxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0XVoxk1A, 1, m, &cVar_0XVoxk1A_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7neoFJRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jKnAmhxM, HV_BINOP_MULTIPLY, 1, m, &cBinop_jKnAmhxM_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_6dSvbmMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rBshlD7G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rBshlD7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HxCtXQPG, HV_BINOP_MULTIPLY, 1, m, &cBinop_HxCtXQPG_sendMessage);
}

void Heavy_WSTD_3Q::cVar_0XVoxk1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gpjbGk8s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_tqtMaix1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gWxKflKj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_DjVoanDP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LYGerc5C_sendMessage);
}

void Heavy_WSTD_3Q::cVar_og5TLoeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_rXFfztfa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0avkbop4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_5So1b9n3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Ug7fCbC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_3VIpY2rJ_sendMessage);
}

void Heavy_WSTD_3Q::cSend_IpQKHnKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6V1hFYDH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_sHWwyTLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dlDwM6xD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Ta2ZY7Hz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zEdrQnEL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_GhaHZjXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fQuFe17O_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fQuFe17O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1yWy1LxB, HV_BINOP_MULTIPLY, 1, m, &cBinop_1yWy1LxB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1yWy1LxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ugNMpHga_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ugNMpHga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ta2ZY7Hz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_gpjbGk8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qeLg7QDN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qeLg7QDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ffAo1rR4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wHujtyac_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PwP7F5wA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gtOexHJo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1GYbB1KS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C1UxHs7P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_nvuhOJqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eHMbFjJ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_jKnAmhxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ozMktxgw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_HxCtXQPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VIGBgIDU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_KAoLasOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tqtMaix1, 0, m, &cVar_tqtMaix1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fFw8ed0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_og5TLoeJ, 1, m, &cVar_og5TLoeJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_gWxKflKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_og5TLoeJ, 0, m, &cVar_og5TLoeJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LYGerc5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0XVoxk1A, 0, m, &cVar_0XVoxk1A_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ffAo1rR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HxCtXQPG, HV_BINOP_MULTIPLY, 0, m, &cBinop_HxCtXQPG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wHujtyac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jKnAmhxM, HV_BINOP_MULTIPLY, 0, m, &cBinop_jKnAmhxM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PwP7F5wA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nvuhOJqJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_nvuhOJqJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_gtOexHJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1GYbB1KS, HV_BINOP_MULTIPLY, 0, m, &cBinop_1GYbB1KS_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_x23FIya0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bJ9pk6LC, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_vO7Qdc42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8ShhiqkY, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xSWNf3OK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QKJL6KuX, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_znmRIyGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_A81ewwIk, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_FzCTuK4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NmWdnYyF, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_gNqHv1R9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NMy8ahws_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_NMy8ahws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sm2DNsaG, HV_BINOP_DIVIDE, 1, m, &cBinop_sm2DNsaG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7N22Eza6_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_c2pyu3j0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_GzXbHZSP_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_mtO9lkBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_c2pyu3j0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GzXbHZSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sm2DNsaG, HV_BINOP_DIVIDE, 0, m, &cBinop_sm2DNsaG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7N22Eza6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mtO9lkBZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_sm2DNsaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sV9Qz1uV, HV_BINOP_MULTIPLY, 1, m, &cBinop_sV9Qz1uV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sV9Qz1uV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qhCaVDus_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x1HAZ9X1_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_rjADMm9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_maNPReQm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_vBoK2I0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0oe23g2f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_sQOjVxo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_PQGU8VtW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PQGU8VtW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sV9Qz1uV, HV_BINOP_MULTIPLY, 0, m, &cBinop_sV9Qz1uV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ccxRv5KD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_SCgsEBHE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SCgsEBHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3raKgWaz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_7SVjgLF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lJpk5Omi, HV_BINOP_MULTIPLY, 1, m, &cBinop_lJpk5Omi_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_qal3V0H2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RdFoHI91_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RdFoHI91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7SVjgLF0_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_mbvNHAZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HZXPAbk8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HZXPAbk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_40ZFxWqE, HV_BINOP_MULTIPLY, 1, m, &cBinop_40ZFxWqE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kPHurJ1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hgUqzAop, HV_BINOP_MULTIPLY, 1, m, &cBinop_hgUqzAop_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_cTZe0PeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LizjQaN0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LizjQaN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kPHurJ1U_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aVCeod6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1XWmtF9t, 1, m, &cVar_1XWmtF9t_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jQGhI4iD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4f6f2PPw, HV_BINOP_MULTIPLY, 1, m, &cBinop_4f6f2PPw_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_V8t5XZgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_e2Vt5E6S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_e2Vt5E6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kshsFCO0, HV_BINOP_MULTIPLY, 1, m, &cBinop_kshsFCO0_sendMessage);
}

void Heavy_WSTD_3Q::cVar_1XWmtF9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ds302Q5G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_NRXJ9Gj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NucHdNEE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_sQOjVxo4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rl6xyMca_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ajDxFSAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ccxRv5KD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_x1HAZ9X1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_vBoK2I0S_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qhCaVDus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_rjADMm9G_sendMessage);
}

void Heavy_WSTD_3Q::cSend_maNPReQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_b9P8fxx1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_0oe23g2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_93T7PDWy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_y9xkJAuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7bTsuScr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_3raKgWaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XmCKjE8Z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XmCKjE8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GW1odgNt, HV_BINOP_MULTIPLY, 1, m, &cBinop_GW1odgNt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GW1odgNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2wLL4bM2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2wLL4bM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_y9xkJAuG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ds302Q5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1c2KQjb4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1c2KQjb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_erwPNI7t_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l22efZVf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CpsQ3o1z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GVrhc4Ue_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_njqoL8gY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cdv4KLRM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lJpk5Omi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x23FIya0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_40ZFxWqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vO7Qdc42_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_hgUqzAop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xSWNf3OK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_4f6f2PPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_znmRIyGL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_kshsFCO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FzCTuK4o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_u1QHxlK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ajDxFSAX, 1, m, &cVar_ajDxFSAX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Xi3kkCbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NRXJ9Gj8, 0, m, &cVar_NRXJ9Gj8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GVrhc4Ue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hgUqzAop, HV_BINOP_MULTIPLY, 0, m, &cBinop_hgUqzAop_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CpsQ3o1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4f6f2PPw, HV_BINOP_MULTIPLY, 0, m, &cBinop_4f6f2PPw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_erwPNI7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_l22efZVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kshsFCO0, HV_BINOP_MULTIPLY, 0, m, &cBinop_kshsFCO0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_cdv4KLRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lJpk5Omi, HV_BINOP_MULTIPLY, 0, m, &cBinop_lJpk5Omi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_njqoL8gY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_40ZFxWqE, HV_BINOP_MULTIPLY, 0, m, &cBinop_40ZFxWqE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NucHdNEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ajDxFSAX, 0, m, &cVar_ajDxFSAX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Rl6xyMca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1XWmtF9t, 0, m, &cVar_1XWmtF9t_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kzqxGMMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mM1qXAZI, 1, m, &cIf_mM1qXAZI_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_AOS0TzEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_keYfOPKk, m);
}

void Heavy_WSTD_3Q::cBinop_4C0X6VJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AOS0TzEa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_voH9qp0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mM1qXAZI, 0, m, &cIf_mM1qXAZI_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_ZubdDSjG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_o0wAOYV0, 0, m, &cSlice_o0wAOYV0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fL10RYIh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_o0wAOYV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xMqw5Yrw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xMqw5Yrw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_GcT3rO3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xMqw5Yrw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_xMqw5Yrw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0MLoNGvw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_KApKPzux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pb4QvjbI_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_TnyRro4O, 0, m, &cIf_TnyRro4O_sendMessage);
}

void Heavy_WSTD_3Q::cIf_TnyRro4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jmamyo4W_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_el3dvNRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WKh9vMLk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_hMahuvZT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_pJJeu1ME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bp8oOH6S, HV_BINOP_POW, 0, m, &cBinop_Bp8oOH6S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Bp8oOH6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XhJVaLjN, 0, m, &cIf_XhJVaLjN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_t1niaNQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_0ViuAySB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_O6CwOfQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_el3dvNRO, 0, m, &cIf_el3dvNRO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HLTWVOcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HcHlX8cW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HcHlX8cW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_el3dvNRO, 1, m, &cIf_el3dvNRO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hMahuvZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_t1niaNQB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_WKh9vMLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_XhJVaLjN, 0, m, &cIf_XhJVaLjN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0ViuAySB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bp8oOH6S, HV_BINOP_POW, 1, m, &cBinop_Bp8oOH6S_sendMessage);
  cMsg_pJJeu1ME_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_XhJVaLjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_94IAxaPE, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_pb4QvjbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TnyRro4O, 1, m, &cIf_TnyRro4O_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jmamyo4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BPRriYxV, HV_BINOP_GREATER_THAN, 1, m, &cBinop_BPRriYxV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IQj1meRz, HV_BINOP_EQ, 1, m, &cBinop_IQj1meRz_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ROq7Ke4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lwr8e8Z0, HV_BINOP_ADD, 0, m, &cBinop_Lwr8e8Z0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Lwr8e8Z0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HLTWVOcf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O6CwOfQy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BPRriYxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XhJVaLjN, 1, m, &cIf_XhJVaLjN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IQj1meRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dId9RsGo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_dId9RsGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_94IAxaPE, m);
}

void Heavy_WSTD_3Q::cCast_OhgR7au6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KApKPzux, 0, m, &cVar_KApKPzux_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Kp8DDLAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lwr8e8Z0, HV_BINOP_ADD, 1, m, &cBinop_Lwr8e8Z0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BPRriYxV, HV_BINOP_GREATER_THAN, 0, m, &cBinop_BPRriYxV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IQj1meRz, HV_BINOP_EQ, 0, m, &cBinop_IQj1meRz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UuQlwP50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ROq7Ke4b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_YrNzxWBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_FkjBet8E_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Jt3IBeTm, 0, m, &cIf_Jt3IBeTm_sendMessage);
}

void Heavy_WSTD_3Q::cIf_Jt3IBeTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jIudkF8T_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_IA0K7no5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_oqq03jJt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ztZBUSYr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_In9XPLdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_71XABWSG, HV_BINOP_POW, 0, m, &cBinop_71XABWSG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_71XABWSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RCDSjiXz, 0, m, &cIf_RCDSjiXz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VCPmxn77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_yTQOCaNk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_s1Uefrbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wK0zTHyM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qyvT6RHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IA0K7no5, 0, m, &cIf_IA0K7no5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wK0zTHyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IA0K7no5, 1, m, &cIf_IA0K7no5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ztZBUSYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_VCPmxn77_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_oqq03jJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_RCDSjiXz, 0, m, &cIf_RCDSjiXz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yTQOCaNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_71XABWSG, HV_BINOP_POW, 1, m, &cBinop_71XABWSG_sendMessage);
  cMsg_In9XPLdj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_RCDSjiXz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WD6hgB2C_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AWInLBJW_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_m6blVPyH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_FkjBet8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jt3IBeTm, 1, m, &cIf_Jt3IBeTm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jIudkF8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KypuKS2u, HV_BINOP_GREATER_THAN, 1, m, &cBinop_KypuKS2u_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9p9viJek, HV_BINOP_EQ, 1, m, &cBinop_9p9viJek_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_A81XK2Aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WvT6gogf, HV_BINOP_ADD, 0, m, &cBinop_WvT6gogf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WvT6gogf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s1Uefrbq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qyvT6RHE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KypuKS2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RCDSjiXz, 1, m, &cIf_RCDSjiXz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9p9viJek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kmrHrzKi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_kmrHrzKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WD6hgB2C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AWInLBJW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_m6blVPyH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_f4oIEQWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WvT6gogf, HV_BINOP_ADD, 1, m, &cBinop_WvT6gogf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KypuKS2u, HV_BINOP_GREATER_THAN, 0, m, &cBinop_KypuKS2u_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9p9viJek, HV_BINOP_EQ, 0, m, &cBinop_9p9viJek_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HO7cOPNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A81XK2Aa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_15ENubjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YrNzxWBx, 0, m, &cVar_YrNzxWBx_sendMessage);
}

void Heavy_WSTD_3Q::cVar_GEu519xc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8Hz4ojMK_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_BDYAbTXE, 0, m, &cIf_BDYAbTXE_sendMessage);
}

void Heavy_WSTD_3Q::cIf_BDYAbTXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LKxnoQbW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_Wk5UwxWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_KsKQulvG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_BquMtFgB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_hKzh2Wow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_R0X6u1J2, HV_BINOP_POW, 0, m, &cBinop_R0X6u1J2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_R0X6u1J2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Un4Nnjw7, 0, m, &cIf_Un4Nnjw7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZIvb1dqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_lsxpQhyw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0BTY3XRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wk5UwxWA, 0, m, &cIf_Wk5UwxWA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_cCM5e95m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Uvws5am0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Uvws5am0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wk5UwxWA, 1, m, &cIf_Wk5UwxWA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BquMtFgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ZIvb1dqz_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_KsKQulvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Un4Nnjw7, 0, m, &cIf_Un4Nnjw7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lsxpQhyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R0X6u1J2, HV_BINOP_POW, 1, m, &cBinop_R0X6u1J2_sendMessage);
  cMsg_hKzh2Wow_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_Un4Nnjw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Ef3Mx02W, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_8Hz4ojMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BDYAbTXE, 1, m, &cIf_BDYAbTXE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LKxnoQbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_msRlHn5W, HV_BINOP_GREATER_THAN, 1, m, &cBinop_msRlHn5W_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wRMlHKSQ, HV_BINOP_EQ, 1, m, &cBinop_wRMlHKSQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4K88w7FT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dBGs0kAB, HV_BINOP_ADD, 0, m, &cBinop_dBGs0kAB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dBGs0kAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cCM5e95m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0BTY3XRs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_msRlHn5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Un4Nnjw7, 1, m, &cIf_Un4Nnjw7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wRMlHKSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SyV7c93i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_SyV7c93i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ef3Mx02W, m);
}

void Heavy_WSTD_3Q::cCast_kbNyJ1Ka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GEu519xc, 0, m, &cVar_GEu519xc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7wfGx65g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dBGs0kAB, HV_BINOP_ADD, 1, m, &cBinop_dBGs0kAB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_msRlHn5W, HV_BINOP_GREATER_THAN, 0, m, &cBinop_msRlHn5W_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wRMlHKSQ, HV_BINOP_EQ, 0, m, &cBinop_wRMlHKSQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_a0cCNMP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4K88w7FT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_zNAUYq1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Xb4vVoad, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_f1iB4iws_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9hfac1ea, 0, m, &cSlice_9hfac1ea_sendMessage);
      break;
    }
    default: {
      cSwitchcase_A9nOt0v5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_9hfac1ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9hfurKMM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9hfurKMM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_2gJt4OU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9hfurKMM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_9hfurKMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_126za1dg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_A9nOt0v5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_npI6H1c8, 0, m, &cSlice_npI6H1c8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZubdDSjG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_npI6H1c8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nzencNmi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nzencNmi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_oj6s5xCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nzencNmi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_nzencNmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LlInkqfs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_fL10RYIh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WrbOwLhx, 0, m, &cSlice_WrbOwLhx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rAb3TcOe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_WrbOwLhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yzAgjKnM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yzAgjKnM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_91cfFI19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yzAgjKnM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_yzAgjKnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ykr1ZJ5g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_rAb3TcOe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pH1FVXXo, 0, m, &cSlice_pH1FVXXo_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_pH1FVXXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wz1i1xhM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wz1i1xhM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_9tuhUBVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wz1i1xhM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_wz1i1xhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_C08YvRR1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_5jDO12AA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qmpdT7kh, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_lBRaVaEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FouHN0Ke, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_UXLm2scv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hKOJzvIV, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Eh30GOC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WHOIihFM, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_FVnbbSN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bp1CWXR4, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xh0MNXID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_k648PPdf_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_k648PPdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wbqmvSLg, HV_BINOP_DIVIDE, 1, m, &cBinop_wbqmvSLg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qgL9toTb_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_uer4TQKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_RUWmqGvM_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_8RbISRw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_uer4TQKH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RUWmqGvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wbqmvSLg, HV_BINOP_DIVIDE, 0, m, &cBinop_wbqmvSLg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qgL9toTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8RbISRw0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_wbqmvSLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QHuERylh, HV_BINOP_MULTIPLY, 1, m, &cBinop_QHuERylh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QHuERylh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wJU9Ogpc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dcs987zf_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_jP9ZmtdP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XVnveQzq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_TdhHP1Tj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CZpPG2Zh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_9Gy9KB9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_i1txQlrL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_i1txQlrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QHuERylh, HV_BINOP_MULTIPLY, 0, m, &cBinop_QHuERylh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8Pl1xu0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_TD1N5xdy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TD1N5xdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OypRlfJA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_9aaFIi2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aBu7nU74, 1, m, &cVar_aBu7nU74_sendMessage);
}

void Heavy_WSTD_3Q::cVar_aBu7nU74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZeteZlTj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_8zFQ2gKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b2lKRIGZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_b2lKRIGZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ausvgq6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8zFQ2gKR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3rDoHPJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CnoIjT4p_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CnoIjT4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V4IWAgjr, HV_BINOP_MULTIPLY, 1, m, &cBinop_V4IWAgjr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BVtRbT5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V0koRUlI, HV_BINOP_MULTIPLY, 1, m, &cBinop_V0koRUlI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_D5ircQ70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BVtRbT5M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eGcordOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2sVbGwuo, HV_BINOP_MULTIPLY, 1, m, &cBinop_2sVbGwuo_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_nRVzqbQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9lH5NdJI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9lH5NdJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8p1APkWT, HV_BINOP_MULTIPLY, 1, m, &cBinop_8p1APkWT_sendMessage);
}

void Heavy_WSTD_3Q::cVar_8XRmuHWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZ3ex8fA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_9Gy9KB9A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uUDDL8wq_sendMessage);
}

void Heavy_WSTD_3Q::cVar_7utqotWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8Pl1xu0H_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wJU9Ogpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_jP9ZmtdP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Dcs987zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_TdhHP1Tj_sendMessage);
}

void Heavy_WSTD_3Q::cSend_XVnveQzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_n48RdCIG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_CZpPG2Zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gpGpVDrN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_CCQ2Qs8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lLxtQnRa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_OypRlfJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jeiOeF02_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jeiOeF02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I2MyVZAH, HV_BINOP_MULTIPLY, 1, m, &cBinop_I2MyVZAH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_I2MyVZAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lN1lglCv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lN1lglCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CCQ2Qs8u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ZeteZlTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9CIdyNYB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9CIdyNYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ikc33e2B_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jO5SbQZq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l74BsERR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QlIZB5p4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lIdV5CsQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LEzDgIqD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_b2lKRIGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5jDO12AA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_V4IWAgjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lBRaVaEz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_V0koRUlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UXLm2scv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_2sVbGwuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Eh30GOC8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_8p1APkWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FVnbbSN4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_JSSruxcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7utqotWt, 1, m, &cVar_7utqotWt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Drfx1QMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8XRmuHWv, 0, m, &cVar_8XRmuHWv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Ikc33e2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_lIdV5CsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V4IWAgjr, HV_BINOP_MULTIPLY, 0, m, &cBinop_V4IWAgjr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_l74BsERR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2sVbGwuo, HV_BINOP_MULTIPLY, 0, m, &cBinop_2sVbGwuo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QlIZB5p4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V0koRUlI, HV_BINOP_MULTIPLY, 0, m, &cBinop_V0koRUlI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LEzDgIqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b2lKRIGZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_b2lKRIGZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jO5SbQZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8p1APkWT, HV_BINOP_MULTIPLY, 0, m, &cBinop_8p1APkWT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uUDDL8wq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aBu7nU74, 0, m, &cVar_aBu7nU74_sendMessage);
}

void Heavy_WSTD_3Q::cCast_aZ3ex8fA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7utqotWt, 0, m, &cVar_7utqotWt_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_gk6QG6Ld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XHo7CS2B, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_bHDjWwlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d7TnzUau, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_8cscXeZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8x0yBeXT, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_6ewwZG04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b0pdyTk1, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_VDjVn0Qr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iorKR9Gr_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_iorKR9Gr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vNkK16Hw, HV_BINOP_DIVIDE, 1, m, &cBinop_vNkK16Hw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QThOAIMA_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_2h30cIPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_TEiXJQes_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lGB3LUIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_2h30cIPx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TEiXJQes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vNkK16Hw, HV_BINOP_DIVIDE, 0, m, &cBinop_vNkK16Hw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QThOAIMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lGB3LUIq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_vNkK16Hw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IaA8PWiA, HV_BINOP_MULTIPLY, 1, m, &cBinop_IaA8PWiA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IaA8PWiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xYEPO18E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HHQSDeES_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_GojoKYFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UsrVXZTJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_u2b2qRqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Xmovaknn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Qc4aD7r5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_1bN1jVv2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1bN1jVv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IaA8PWiA, HV_BINOP_MULTIPLY, 0, m, &cBinop_IaA8PWiA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2jAoknbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_lND2oTK6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lND2oTK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7TZimP0i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_OwU8k4n7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JAxBqOFd, HV_BINOP_MULTIPLY, 1, m, &cBinop_JAxBqOFd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kWw1P6zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v5JlgsrJ, 1, m, &cVar_v5JlgsrJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7tMIwe4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b9Pmonv1, HV_BINOP_MULTIPLY, 1, m, &cBinop_b9Pmonv1_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_832IMrnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jJoD6gA4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jJoD6gA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6RttKGxO, HV_BINOP_MULTIPLY, 1, m, &cBinop_6RttKGxO_sendMessage);
}

void Heavy_WSTD_3Q::cVar_v5JlgsrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OrhMNgW6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_MX4g5vNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hCnlCoOg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Qc4aD7r5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4nzieyUl_sendMessage);
}

void Heavy_WSTD_3Q::cVar_BAneZezp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_2jAoknbE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xYEPO18E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_GojoKYFU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HHQSDeES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_u2b2qRqE_sendMessage);
}

void Heavy_WSTD_3Q::cSend_UsrVXZTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fbeqbJtq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Xmovaknn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jPgZgoYN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_YZpZeFy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_stsn3JCQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_7TZimP0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yVqSpp7d_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yVqSpp7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U82vo58l, HV_BINOP_MULTIPLY, 1, m, &cBinop_U82vo58l_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_U82vo58l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_z1pUU368_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_z1pUU368_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YZpZeFy3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_OrhMNgW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MVeSSN61_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MVeSSN61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZOu4Uujm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6hEEYTmk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HbFw8MEV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tRkgahBS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QgMq1Cfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gk6QG6Ld_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_JAxBqOFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bHDjWwlm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_b9Pmonv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8cscXeZf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6RttKGxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6ewwZG04_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_bcBj7nka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BAneZezp, 1, m, &cVar_BAneZezp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HUeKwRnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MX4g5vNQ, 0, m, &cVar_MX4g5vNQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4nzieyUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v5JlgsrJ, 0, m, &cVar_v5JlgsrJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hCnlCoOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BAneZezp, 0, m, &cVar_BAneZezp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6hEEYTmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b9Pmonv1, HV_BINOP_MULTIPLY, 0, m, &cBinop_b9Pmonv1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZOu4Uujm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6RttKGxO, HV_BINOP_MULTIPLY, 0, m, &cBinop_6RttKGxO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tRkgahBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QgMq1Cfo, HV_BINOP_MULTIPLY, 0, m, &cBinop_QgMq1Cfo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HbFw8MEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JAxBqOFd, HV_BINOP_MULTIPLY, 0, m, &cBinop_JAxBqOFd_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_vAcvbNBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2PrwNZRW, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_yDK01CNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5SZz1qwR, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_OfSXvY8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7xhp22u2, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_OlRomm92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V3kAG9EL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_3yn7CLkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oeLL4ZJa, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_1oONsrkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JeK8pN9B_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_JeK8pN9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ijIqsxqq, HV_BINOP_DIVIDE, 1, m, &cBinop_ijIqsxqq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gs8j1WXc_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_cJd8cIjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_aVe37Wvg_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_mo1g5vdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_cJd8cIjR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aVe37Wvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ijIqsxqq, HV_BINOP_DIVIDE, 0, m, &cBinop_ijIqsxqq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Gs8j1WXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mo1g5vdt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ijIqsxqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lFAZHB8z, HV_BINOP_MULTIPLY, 1, m, &cBinop_lFAZHB8z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lFAZHB8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1wMLdu7V_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P58k0gPN_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_8dO7KwyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tSQJHKGQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_2OX6PtkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9tySZewX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_QARaYfHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_vvNh4VFC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vvNh4VFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lFAZHB8z, HV_BINOP_MULTIPLY, 0, m, &cBinop_lFAZHB8z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lHDyrT7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ZgHIHNXd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZgHIHNXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3DP5nY3D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_H1gEo1o0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8zSSzHco, HV_BINOP_MULTIPLY, 1, m, &cBinop_8zSSzHco_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_iBFAtqpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PaA6qvSH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PaA6qvSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_H1gEo1o0_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_3VRiPPsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5A9GWeqG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5A9GWeqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZJqQ17nr, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZJqQ17nr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6ugWQ5v3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2NM5qa5a, HV_BINOP_MULTIPLY, 1, m, &cBinop_2NM5qa5a_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_3Cgz7pjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Nnpqhkwb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Nnpqhkwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6ugWQ5v3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_udtZgNyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a6VyYyPF, 1, m, &cVar_a6VyYyPF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HZYxjiPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lyUQSu49, HV_BINOP_MULTIPLY, 1, m, &cBinop_lyUQSu49_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_pLcAT5uo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZRMs61P2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZRMs61P2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zHCGltPm, HV_BINOP_MULTIPLY, 1, m, &cBinop_zHCGltPm_sendMessage);
}

void Heavy_WSTD_3Q::cVar_a6VyYyPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iTiFwi3W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_RH7QeR1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tBofFD1q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_QARaYfHD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZrxRVo9V_sendMessage);
}

void Heavy_WSTD_3Q::cVar_3IFZhRXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lHDyrT7w_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1wMLdu7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_8dO7KwyQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_P58k0gPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_2OX6PtkY_sendMessage);
}

void Heavy_WSTD_3Q::cSend_tSQJHKGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_C7YXGuiD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_9tySZewX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RC1STGN5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_pAcdHgvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VvNgBcDy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_3DP5nY3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xOuXv2Pg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xOuXv2Pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dpHvFnWd, HV_BINOP_MULTIPLY, 1, m, &cBinop_dpHvFnWd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dpHvFnWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IibHLrYa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IibHLrYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pAcdHgvN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_iTiFwi3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bUp9pZI2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bUp9pZI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HCeBtMhE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FyvEuw55_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Resrhw4a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iL5L7E82_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z9999lDQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zrPrClRi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8zSSzHco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vAcvbNBg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ZJqQ17nr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yDK01CNr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_2NM5qa5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OfSXvY8T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_lyUQSu49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OlRomm92_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_zHCGltPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3yn7CLkb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_0Y4vzU90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RH7QeR1s, 0, m, &cVar_RH7QeR1s_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MVqTc8Ie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3IFZhRXy, 1, m, &cVar_3IFZhRXy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Resrhw4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lyUQSu49, HV_BINOP_MULTIPLY, 0, m, &cBinop_lyUQSu49_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FyvEuw55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zHCGltPm, HV_BINOP_MULTIPLY, 0, m, &cBinop_zHCGltPm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HCeBtMhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_iL5L7E82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2NM5qa5a, HV_BINOP_MULTIPLY, 0, m, &cBinop_2NM5qa5a_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zrPrClRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8zSSzHco, HV_BINOP_MULTIPLY, 0, m, &cBinop_8zSSzHco_sendMessage);
}

void Heavy_WSTD_3Q::cCast_z9999lDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZJqQ17nr, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZJqQ17nr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZrxRVo9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a6VyYyPF, 0, m, &cVar_a6VyYyPF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tBofFD1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3IFZhRXy, 0, m, &cVar_3IFZhRXy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WD6hgB2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zNAUYq1z, 1, m, &cIf_zNAUYq1z_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_znY8UY0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Xb4vVoad, m);
}

void Heavy_WSTD_3Q::cBinop_AWInLBJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_znY8UY0p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_m6blVPyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zNAUYq1z, 0, m, &cIf_zNAUYq1z_sendMessage);
}

void Heavy_WSTD_3Q::cVar_MFATBjh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DL8Xbod5, HV_BINOP_DIVIDE, 0, m, &cBinop_DL8Xbod5_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ErGEJiKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YWtIw7s7, HV_BINOP_DIVIDE, 1, m, &cBinop_YWtIw7s7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DL8Xbod5, HV_BINOP_DIVIDE, 1, m, &cBinop_DL8Xbod5_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_QnPIEOVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GdiKkrtT, HV_BINOP_DIVIDE, 0, m, &cBinop_GdiKkrtT_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_2bmr7pu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GdiKkrtT, HV_BINOP_DIVIDE, 1, m, &cBinop_GdiKkrtT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KjOp4hyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YWtIw7s7, HV_BINOP_DIVIDE, 0, m, &cBinop_YWtIw7s7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qbTieCyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MFATBjh6, 0, m, &cVar_MFATBjh6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_eGz8kHnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ErGEJiKc, 0, m, &cVar_ErGEJiKc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YWtIw7s7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_QnPIEOVX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DL8Xbod5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_2bmr7pu4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GdiKkrtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_wiDATRB6_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_UoGo7KOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_Pa8Kpn4M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IunQJDsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_dT4ODTKi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wiDATRB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IunQJDsG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dT4ODTKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_UoGo7KOO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Pa8Kpn4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rYb9BU0W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_zpSeh4zV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EmNiVX4A_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_f1iB4iws_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_LOi6FqlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EmNiVX4A_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_f1iB4iws_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ETPb0BqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EmNiVX4A_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_f1iB4iws_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_g9RhyM1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EmNiVX4A_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_f1iB4iws_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_rYb9BU0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EmNiVX4A_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_f1iB4iws_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_943bUim3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_AA2T9yvy, 0, m, &cVar_AA2T9yvy_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_FfwWXuUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_niRulR8a, 0, m, &cVar_niRulR8a_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5v68Tw5P, 0, m, &cVar_5v68Tw5P_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5sjXZoMv, 0, m, &cVar_5sjXZoMv_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_U0V4Ekui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_niRulR8a, 0, m, &cVar_niRulR8a_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_1UdX3PTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5v68Tw5P, 0, m, &cVar_5v68Tw5P_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_K6jwdQhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5sjXZoMv, 0, m, &cVar_5sjXZoMv_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_PrRFGB9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tqtMaix1, 0, m, &cVar_tqtMaix1_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_x04G0pcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fFw8ed0n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KAoLasOR_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_RP79Hr9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6J5lUQ2S_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1LSs9Dao_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vwHoah1C_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_nIP2aPSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z9NjCTVG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pxp8cFzU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1hBp4b0b_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_dL2CdiDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zKrHk4m8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_STXiUMG5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PFUZ9V6j_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_U0Rgcfrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p6zKzh91_sendMessage(_c, 0, m);
  cMsg_OHTEX8xB_sendMessage(_c, 0, m);
  cMsg_gNqHv1R9_sendMessage(_c, 0, m);
  cMsg_xh0MNXID_sendMessage(_c, 0, m);
  cMsg_VDjVn0Qr_sendMessage(_c, 0, m);
  cMsg_1oONsrkf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NbuJXogb, 0, m, &cVar_NbuJXogb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tqtMaix1, 0, m, &cVar_tqtMaix1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NRXJ9Gj8, 0, m, &cVar_NRXJ9Gj8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8XRmuHWv, 0, m, &cVar_8XRmuHWv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MX4g5vNQ, 0, m, &cVar_MX4g5vNQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RH7QeR1s, 0, m, &cVar_RH7QeR1s_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VlZKe685, 0, m, &cVar_VlZKe685_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Yzixk9P4, 0, m, &cVar_Yzixk9P4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_T7wG9dcQ, 0, m, &cVar_T7wG9dcQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sme5eVY5, 0, m, &cVar_sme5eVY5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aqhcZlfk, 0, m, &cVar_aqhcZlfk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E5Pyiv79, 0, m, &cVar_E5Pyiv79_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wtrPQj8E, 0, m, &cVar_wtrPQj8E_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_muCXkArh, 0, m, &cVar_muCXkArh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GcT3rO3K, 0, m, &cVar_GcT3rO3K_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KApKPzux, 0, m, &cVar_KApKPzux_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YrNzxWBx, 0, m, &cVar_YrNzxWBx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GEu519xc, 0, m, &cVar_GEu519xc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2gJt4OU5, 0, m, &cVar_2gJt4OU5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oj6s5xCy, 0, m, &cVar_oj6s5xCy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_91cfFI19, 0, m, &cVar_91cfFI19_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9tuhUBVK, 0, m, &cVar_9tuhUBVK_sendMessage);
  cMsg_FfwWXuUV_sendMessage(_c, 0, m);
  cMsg_943bUim3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_0LF2JA9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KJ7lPaRZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_KJ7lPaRZ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_6LL9mpAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9YDpkwR3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fDlmCEQL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iXQWFeS3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_mnsNdhVH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_UIlOJ8Zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_s21sXv2m_sendMessage);
  cMsg_613mELo1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_6V1hFYDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1yWy1LxB, HV_BINOP_MULTIPLY, 0, m, &cBinop_1yWy1LxB_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_dlDwM6xD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_7neoFJRq_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_zEdrQnEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1GYbB1KS, HV_BINOP_MULTIPLY, 1, m, &cBinop_1GYbB1KS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vwLnR9e1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lcCRucxt_sendMessage);
  cMsg_6dSvbmMP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_b9P8fxx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GW1odgNt, HV_BINOP_MULTIPLY, 0, m, &cBinop_GW1odgNt_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_93T7PDWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qal3V0H2_sendMessage(_c, 0, m);
  cMsg_mbvNHAZl_sendMessage(_c, 0, m);
  cMsg_cTZe0PeD_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_jQGhI4iD_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_7bTsuScr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_aVCeod6t_sendMessage);
  cMsg_V8t5XZgi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_0MLoNGvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MX4g5vNQ, 0, m, &cVar_MX4g5vNQ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_C08YvRR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bcBj7nka_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HUeKwRnY_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_126za1dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OhgR7au6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kp8DDLAh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UuQlwP50_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Ykr1ZJ5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kbNyJ1Ka_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7wfGx65g_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a0cCNMP1_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_LlInkqfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_15ENubjV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f4oIEQWC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HO7cOPNL_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_n48RdCIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I2MyVZAH, HV_BINOP_MULTIPLY, 0, m, &cBinop_I2MyVZAH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_gpGpVDrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ausvgq6D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3rDoHPJe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_D5ircQ70_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_eGcordOx_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_lLxtQnRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9aaFIi2g_sendMessage);
  cMsg_nRVzqbQK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_fbeqbJtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U82vo58l, HV_BINOP_MULTIPLY, 0, m, &cBinop_U82vo58l_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_jPgZgoYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_7tMIwe4q_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_stsn3JCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QgMq1Cfo, HV_BINOP_MULTIPLY, 1, m, &cBinop_QgMq1Cfo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_OwU8k4n7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kWw1P6zx_sendMessage);
  cMsg_832IMrnZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_C7YXGuiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dpHvFnWd, HV_BINOP_MULTIPLY, 0, m, &cBinop_dpHvFnWd_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_RC1STGN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iBFAtqpl_sendMessage(_c, 0, m);
  cMsg_3VRiPPsD_sendMessage(_c, 0, m);
  cMsg_3Cgz7pjX_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_HZYxjiPr_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_VvNgBcDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_udtZgNyf_sendMessage);
  cMsg_pLcAT5uo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_AxolXX30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AA2T9yvy, 0, m, &cVar_AA2T9yvy_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_RRIEAxdA, VOf(Bf0));
    __hv_line_f(&sLine_OYRv3L6z, VOf(Bf1));
    __hv_line_f(&sLine_R9R1C9Gq, VOf(Bf2));
    __hv_line_f(&sLine_YhlfLYDc, VOf(Bf3));
    __hv_line_f(&sLine_I2xfgYvA, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_8vjDc1tO, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_pdiz2DWB, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_b9nzQLOC, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_7eI8003V, VOf(Bf1));
    __hv_line_f(&sLine_mqsVxGIM, VOf(Bf0));
    __hv_line_f(&sLine_imf7U8AG, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_8HcvDoDq, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_keYfOPKk, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_bJ9pk6LC, VOf(Bf5));
    __hv_line_f(&sLine_8ShhiqkY, VOf(Bf1));
    __hv_line_f(&sLine_QKJL6KuX, VOf(Bf2));
    __hv_line_f(&sLine_A81ewwIk, VOf(Bf4));
    __hv_line_f(&sLine_NmWdnYyF, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_mMvczGl6, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_oNOJwrPb, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_qmpdT7kh, VOf(Bf6));
    __hv_line_f(&sLine_FouHN0Ke, VOf(Bf2));
    __hv_line_f(&sLine_hKOJzvIV, VOf(Bf1));
    __hv_line_f(&sLine_WHOIihFM, VOf(Bf5));
    __hv_line_f(&sLine_Bp1CWXR4, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_oQM06tDZ, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_94IAxaPE, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_XHo7CS2B, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_d7TnzUau, VOf(Bf2));
    __hv_line_f(&sLine_8x0yBeXT, VOf(Bf6));
    __hv_line_f(&sLine_b0pdyTk1, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_Nbjuwmjk, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Xb4vVoad, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_2PrwNZRW, VOf(Bf8));
    __hv_line_f(&sLine_5SZz1qwR, VOf(Bf2));
    __hv_line_f(&sLine_7xhp22u2, VOf(Bf1));
    __hv_line_f(&sLine_V3kAG9EL, VOf(Bf7));
    __hv_line_f(&sLine_oeLL4ZJa, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_T4dDZckt, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Ef3Mx02W, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
